@@ -3,10 +3,10 @@ onetimepass module is designed to work for one-time passwords - HMAC-based and
 time-based. It is compatible with Google Authenticator application and
 applications based on it.
 
-@version: 0.2.0
+@version: 0.2.2
 @author: Tomasz Jaskowski
 @contact: http://github.com/tadeck
-@license: GNU Lesser General Public License (LGPL)
+@license: MIT
 
 >>> secret = b'MFRGGZDFMZTWQ2LK'
 >>> get_hotp(secret, 1) == 765705
@@ -35,10 +35,10 @@ import struct
 import time
 
 __author__ = 'Tomasz Jaskowski <tadeck@gmail.com>'
-__date__ = '23 January 2013'
-__version_info__ = (0, 1, 2)
+__date__ = '12 July 2013'
+__version_info__ = (0, 2, 2)
 __version__ = '%s.%s.%s' % __version_info__
-__license__ = 'GNU Lesser General Public License (LGPL)'
+__license__ = 'MIT'
 
 
 def _is_possible_token(token):
@@ -72,7 +72,7 @@ def get_hotp(secret, intervals_no, as_string=False, casefold=True):
     interval number.
 
     :param secret: the base32-encoded string acting as secret key
-    :type secret: str
+    :type secret: str or unicode
     :param intervals_no: interval number used for getting different tokens, it
         is incremented with each use
     :type intervals_no: int
@@ -91,6 +91,9 @@ def get_hotp(secret, intervals_no, as_string=False, casefold=True):
     >>> result == b'816065'
     True
     """
+    if isinstance(secret, six.string_types):
+        # It is unicode, convert it to bytes
+        secret = secret.encode('utf-8')
     try:
         key = base64.b32decode(secret, casefold=casefold)
     except (TypeError):
@@ -102,6 +105,7 @@ def get_hotp(secret, intervals_no, as_string=False, casefold=True):
     token_base = struct.unpack('>I', hmac_digest[o:o + 4])[0] & 0x7fffffff
     token = token_base % 1000000
     if as_string:
+        # TODO: should as_string=True return unicode, not bytes?
         return six.b('{:06d}'.format(token))
     else:
         return token
